@@ -1464,14 +1464,15 @@ class Molecule:
         fragments = nx.connected_components(self.bonds)
         return [list(f) for f in list(fragments)]
 
-    def limit_solvent_shell(self, num_atoms=0, num_solvents=10):
+    def limit_solvent_shell(self, solute=0, num_atoms=0, num_solvents=10):
         """
         Automatically detects solvent molecules and removes them until you have a set number of solvents or atoms.
 
-        This code assumes that the fragment of interest comes first in the file, which is almost always true but may not be true.
+        The "distance" between molecules is the minimum of the pairwise atomic distances, to emphasize inner-sphere interactions.
 
         Args:
-            num_atoms (int): remove atoms until there are this number (module size of a solvent molecule)
+            solute (int): which fragment is the solute, 0-indexed
+            num_atoms (int): remove atoms until there are this number (modulo the size of a solvent molecule)
             num_solvents (int): remove solvent molecules until there are this number
 
         Returns:
@@ -1481,16 +1482,20 @@ class Molecule:
         assert isinstance(num_solvents, int)
 
         fragments = self.get_components()
+        solute_x = self.geometry[fragments[0]].view(np.ndarray)
 
-        #### not strictly a centroid since it's not mass-weighted.
-        centroids = np.zeros(shape=(len(fragments), 3))
         distances = np.zeros(shape=len(fragments))
         for i, f in enumerate(fragments):
-            centroids[i] = np.mean(self.geometry[f], axis=0)
-            if i > 0:
-                distances[i] = np.linalg.norm(centroids[i] - centroids[0])
+            if i == solute:
+                distances[i] = 0
+            else:
+                solvent_x = self.geometry[f].view(np.ndarray)
+                # cdist is absurdly fast
+                pairwise_distances = cdist(solvent_x, solute_x)
+                distances[i] = np.min(pairwise_distances)
 
         mol = copy.deepcopy(self)
+
         #### reverse order - farthest away comes first
         order = np.argsort(distances)[::-1]
 
@@ -1624,3 +1629,38 @@ class Molecule:
         """
         symbols = {z: get_symbol(z) for z in set(self.atomic_numbers)}
         return [symbols[z] for z in self.atomic_numbers]
+
+    def optimize(self, inplace=True, nprocs=1):
+        """
+        Optimize molecule at the GFN2-xtb level of theory.
+
+        Args:
+            inplace (Bool): whether or not to return a new molecule or simply modify ``self.geometry``
+            nprocs (int): number of processors to use
+        """
+        import cctk.optimize as opt
+        assert isinstance(nprocs, int), "nprocs must be int!"
+        optimized = opt.optimize_molecule(self, nprocs=nprocs)
+
+        if inplace:
+            self.geometry = optimized.geometry
+            return self
+        else:
+            return optimized
+
+    def csearch(self, nprocs=1, constraints=[], logfile=None, noncovalent=False):
+        """
+        Optimize molecule at the GFN2-xtb level of theory.
+
+        Args:
+            nprocs (int): number of processors to use
+            constraints (list): atoms numbers to freeze
+            noncovalent (Bool): whether or not to use non-covalent settings
+            logfile (str): file to write ongoing ``crest`` output to
+
+        Returns
+            ConformationalEnsemble
+        """
+        import cctk.optimize as opt
+        assert isinstance(nprocs, int), "nprocs must be int!"
+        return opt.csearch(self, nprocs=nprocs, constraints=constraints, noncovalent=noncovalent, logfile=logfile)
